/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Torben Jastrow (Fraunhofer FOKUS)
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.appManager.models;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.databind.JsonNode;

@JsonInclude(Include.NON_EMPTY)
public class AppDescription {

	private String id;
	private String name;
	private String description;
	private String version;

	private Boolean highTechnologicalRisk;

	private String jenkinsEndpoint;
	private String jenkinsToken;

	private List<Nfr> nfrs = new ArrayList<>();

	private List<Microservice> microservices = new ArrayList<>();

	private Mcsla mcsla;

	private List<Container> containers = new ArrayList<>();
	private List<VirtualMachine> virtualMachines = new ArrayList<>();

	private List<Pattern> recommendedPatterns = new ArrayList<>();

	private List<SchemaElement> schema = new ArrayList<>();

	private Monitoring monitoring;

	private String applicationInstanceId;

	private Map<String, JsonNode> additionalProperties = new HashMap<>();

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public Boolean getHighTechnologicalRisk() {
		return highTechnologicalRisk;
	}

	public void setHighTechnologicalRisk(Boolean highTechnologicalRisk) {
		this.highTechnologicalRisk = highTechnologicalRisk;
	}

	public String getJenkinsEndpoint() {
		return jenkinsEndpoint;
	}

	public void setJenkinsEndpoint(String jenkinsEndpoint) {
		this.jenkinsEndpoint = jenkinsEndpoint;
	}

	public String getJenkinsToken() {
		return jenkinsToken;
	}

	public void setJenkinsToken(String jenkinsToken) {
		this.jenkinsToken = jenkinsToken;
	}

	public List<Nfr> getNfrs() {
		return nfrs;
	}

	public void setNfrs(List<Nfr> nfrs) {
		this.nfrs = nfrs;
	}

	public List<Microservice> getMicroservices() {
		return microservices;
	}

	public void setMicroservices(List<Microservice> microservices) {
		this.microservices = microservices;
	}

	public Mcsla getMcsla() {
		return mcsla;
	}

	public void setMcsla(Mcsla mcsla) {
		this.mcsla = mcsla;
	}

	public List<Container> getContainers() {
		return containers;
	}

	public void setContainers(List<Container> containers) {
		this.containers = containers;
	}

	public List<VirtualMachine> getVirtualMachines() {
		return virtualMachines;
	}

	public void setVirtualMachines(List<VirtualMachine> virtualMachines) {
		this.virtualMachines = virtualMachines;
	}

	public List<SchemaElement> getSchema() {
		return schema;
	}

	public void setSchema(List<SchemaElement> schema) {
		this.schema = schema;
	}

	public Monitoring getMonitoring() {
		return monitoring;
	}

	public void setMonitoring(Monitoring monitoring) {
		this.monitoring = monitoring;
	}

	public List<Pattern> getRecommendedPatterns() {
		return recommendedPatterns;
	}

	public void setRecommendedPatterns(List<Pattern> recommendedPatterns) {
		this.recommendedPatterns = recommendedPatterns;
	}

	public String getApplicationInstanceId() {
		return applicationInstanceId;
	}

	public void setApplicationInstanceId(String applicationInstanceId) {
		this.applicationInstanceId = applicationInstanceId;
	}

	@JsonAnyGetter
	public Map<String, JsonNode> getAdditionalProperties() {
		return additionalProperties;
	}

	@JsonAnySetter
	public void setAdditionalProperties(String property, JsonNode value) {
		additionalProperties.put(property, value);
	}

}
