/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.appManager.models;

import com.fasterxml.jackson.annotation.*;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.databind.JsonNode;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@JsonTypeInfo(
        use = JsonTypeInfo.Id.NAME,
        include = JsonTypeInfo.As.PROPERTY,
        property = "type",
        visible = true)
@JsonSubTypes({
        @JsonSubTypes.Type(value = AvailabilityNfr.class, name = "Availability"),
        @JsonSubTypes.Type(value = PerformanceNfr.class, name = "Performance"),
        @JsonSubTypes.Type(value = ScalabilityNfr.class, name = "Scalability"),
        @JsonSubTypes.Type(value = LocationNfr.class, name = "Location"),
        @JsonSubTypes.Type(value = CostNfr.class, name = "Cost")})
@JsonInclude(Include.NON_EMPTY)
public class Nfr {

    @JsonTypeId
    private String type;

    private List<String> tags = new ArrayList<>();

    private Map<String, JsonNode> additionalProperties = new HashMap<>();

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public List<String> getTags() {
        return tags;
    }

    public void setTags(List<String> tags) {
        this.tags = tags;
    }

    @JsonAnyGetter
    public Map<String, JsonNode> getAdditionalProperties() {
        return additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperties(String property, JsonNode value) {
        additionalProperties.put(property, value);
    }

}
