/*
 * Copyright (c) 2017 Fraunhofer FOKUS.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the
 * GNU AGPL v3 which accompanies
 * this distribution, and is available at
 * http://www.gnu.org/licenses/agpl.txt
 *
 * Contributors:
 * Simon Dutkowski Fraunhofer FOKUS
 *
 * Initially developed in the context of DECIDE EU project www.DECIDE-h2020.eu
 */
package eu.DECIDEh2020.appManager;

import com.fasterxml.jackson.databind.ObjectMapper;
import eu.DECIDEh2020.appManager.models.AppDescription;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

import java.io.IOException;
import java.nio.file.FileSystems;
import java.nio.file.Path;
import java.util.List;

public class AppDescriptionHelperTest {

    private Logger log = LoggerFactory.getLogger(getClass());

    private AppDescriptionHelper helper;

    @BeforeClass
    public void init() {
        Path path = FileSystems.getDefault().getPath("src/test/resources/DECIDE.json");
        try {
            AppDescription appDescription = new ObjectMapper().readValue(path.toFile(), AppDescription.class);
            helper = AppDescriptionHelper.create(appDescription);
        } catch (IOException e) {
            log.error("reading test resource", e);
            assert false;
        }
    }

    @Test
    public void useFactory() {
        AppDescription appDescription = AppDescriptionFactory.createAppDescription("TestApp");
        AppDescriptionHelper helper = AppDescriptionHelper.create(appDescription);
        assert helper.getGroupMicroservices("should be empty").isEmpty();
    }

    @Test
    public void getGroupMicroservices() {
        assert helper.getGroupMicroservices("TestGroup").size() == 2;
    }

    @Test
    public void getMicroserviceGroups() {
        List<String> groups = helper.getMicroserviceGroups();
        groups.forEach(g -> log.debug(g));
        assert groups.size() == 1;
    }

}
